#include "lcd.h"

void LCD_WaitForReady()
{
  int status = 0x00;
  
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D4_PIN, GPIO_Mode_IN, GPIO_OType_OD, GPIO_Speed_25MHz, GPIO_PuPd_UP);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D5_PIN, GPIO_Mode_IN, GPIO_OType_OD, GPIO_Speed_25MHz, GPIO_PuPd_UP);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D6_PIN, GPIO_Mode_IN, GPIO_OType_OD, GPIO_Speed_25MHz, GPIO_PuPd_UP);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D7_PIN, GPIO_Mode_IN, GPIO_OType_OD, GPIO_Speed_25MHz, GPIO_PuPd_UP);
  
  GPIO_SetBits(LCD_PORT, LCD_RW_PIN);
	
  do { 
    GPIO_SetBits(LCD_PORT, LCD_E_PIN);
		status = GPIO_ReadInputDataBit(LCD_PORT, LCD_D7_PIN);
    GPIO_ResetBits(LCD_PORT, LCD_E_PIN);
	} while (status);
  
  GPIO_ResetBits(LCD_PORT, LCD_RW_PIN);
  
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D4_PIN, GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D5_PIN, GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D6_PIN, GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D7_PIN, GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);
}

void LCD_WriteNibble( int data )
{
  ( data & 0x08 ) ? GPIO_SetBits(LCD_PORT, LCD_D7_PIN) : GPIO_ResetBits(LCD_PORT, LCD_D7_PIN);
  ( data & 0x04 ) ? GPIO_SetBits(LCD_PORT, LCD_D6_PIN) : GPIO_ResetBits(LCD_PORT, LCD_D6_PIN);
  ( data & 0x02 ) ? GPIO_SetBits(LCD_PORT, LCD_D5_PIN) : GPIO_ResetBits(LCD_PORT, LCD_D5_PIN);
  ( data & 0x01 ) ? GPIO_SetBits(LCD_PORT, LCD_D4_PIN) : GPIO_ResetBits(LCD_PORT, LCD_D4_PIN);
}

void LCD_WriteCmd( int data )
{

  GPIO_SetBits(LCD_PORT, LCD_E_PIN);
  LCD_WriteNibble(data>>4);
  GPIO_ResetBits(LCD_PORT, LCD_E_PIN);

  GPIO_SetBits(LCD_PORT, LCD_E_PIN);
  LCD_WriteNibble(data);
  GPIO_ResetBits(LCD_PORT, LCD_E_PIN);
  
  Delay(1);
}

void LCD_WriteData (int data)
{ 

  GPIO_SetBits(LCD_PORT, LCD_RS_PIN);
  GPIO_SetBits(LCD_PORT, LCD_E_PIN);
  LCD_WriteNibble(data>>4);
  GPIO_ResetBits(LCD_PORT, LCD_E_PIN);
  GPIO_ResetBits(LCD_PORT, LCD_RS_PIN);

  GPIO_SetBits(LCD_PORT, LCD_RS_PIN);
  GPIO_SetBits(LCD_PORT, LCD_E_PIN);
  LCD_WriteNibble(data);
  GPIO_ResetBits(LCD_PORT, LCD_E_PIN);
  GPIO_ResetBits(LCD_PORT, LCD_RS_PIN);

  Delay(1);
}

void LCD_ClearScreen()
{
	LCD_WriteCmd(0x01);
}

void LCD_SetLine( int line )
{
	switch ( line ) {
		case 1:	LCD_WriteCmd(0x80);	break;
		case 2:	LCD_WriteCmd(0xC0); break;
	}
}

void LCD_WriteString( int line, char* str )
{
	int	size 	=	strlen(str);
	int	tail	=	16 - size;
	if ( size ) {
		LCD_SetLine(line);
		do {
			LCD_WriteData( *str++ );
		} while (*str);
		for( ; tail; tail-- ) {
			LCD_WriteData(' ');
		}
	}
}

void LCD_Init()
{
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_RS_PIN, GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_RW_PIN, GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_E_PIN,  GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D4_PIN, GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D5_PIN, GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D6_PIN, GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);
  GPIO_InitPin(LCD_PORT, LCD_PORT_CLK, LCD_D7_PIN, GPIO_Mode_OUT, GPIO_OType_PP, GPIO_Speed_25MHz, GPIO_PuPd_DOWN);

  Delay(100);

  LCD_WriteNibble(0x03);
  GPIO_SetBits(LCD_PORT, LCD_E_PIN);
  Delay(1);
  GPIO_ResetBits(LCD_PORT, LCD_E_PIN);
  Delay(5);

  LCD_WriteNibble(0x03);
  GPIO_SetBits(LCD_PORT, LCD_E_PIN);
  Delay(1);
  GPIO_ResetBits(LCD_PORT, LCD_E_PIN);
  Delay(5);

  LCD_WriteNibble(0x03);
  GPIO_SetBits(LCD_PORT, LCD_E_PIN);
  Delay(1);
  GPIO_ResetBits(LCD_PORT, LCD_E_PIN);
  Delay(5);

  LCD_WriteNibble(0x02);
  GPIO_SetBits(LCD_PORT, LCD_E_PIN);
  Delay(1);
  GPIO_ResetBits(LCD_PORT, LCD_E_PIN);
  Delay(5);

  LCD_WriteCmd(0x28);
  LCD_WriteCmd(0x0C);
  LCD_WriteCmd(0x01);
  LCD_WriteCmd(0x06);
  
}
